==> 0.1.2a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/details/StepsAndDetails.kt <==
package details

import AnimateInEffect
import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyListScope
import androidx.compose.foundation.lazy.grid.LazyGridScope
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.foundation.text.selection.SelectionContainer
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import model.Recipe


/**
 * Created by abdulbasit on 29/07/2023.
 */

@OptIn(ExperimentalSharedTransitionApi::class)
internal fun LazyListScope.StepsAndDetails(
    recipe: Recipe,
) {
    item {
        recipeHeader(recipe)
    }

    item {
        ingredientsHeader(recipe)
    }

    ingredients(recipe)

    item {
        stepsHeader(recipe)
    }

    steps(recipe)


}

@Composable
fun recipeHeader(recipe: Recipe)
{
    SelectionContainer {
        Text(
            text = recipe.title,
            style = MaterialTheme.typography.headlineLarge,
            fontWeight = FontWeight.W700,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }

    Text(
        text = recipe.description,
        style = MaterialTheme.typography.bodyMedium,
        modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
    )

    Row {
        Text(
            text = "Prep Time: ".plus(recipe.prepTime.toString()),
            style = MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
        Text(
            text = "Cook Time: ".plus(recipe.cookTime.toString()),
            style = MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }
    Row {
        Text(
            text = "Total Time: ".plus(recipe.cookTime.plus(recipe.prepTime).toString()),
            style = MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
        Text(
            text = "Serving Size: ".plus(recipe.servings),
            style = MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }
}

@Composable
fun ingredientsHeader(recipe: Recipe)
{
    AnimateInEffect(
        recipe = recipe,
        intervalStart = 0 / (recipe.instructions.size + recipe.ingredients.size + 2).toFloat(),
        content = {
            Text(
                text = "INGREDIENTS",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.W700,
                modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
            )
        })
}

@Composable
fun stepsHeader(recipe: Recipe)
{
    AnimateInEffect(
        recipe = recipe,
        intervalStart = (recipe.ingredients.size + 1) / (recipe.instructions.size + recipe.ingredients.size + 2).toFloat(),
        content = {
            Text(
                text = "STEPS",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.W700,
                modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
            )
        }
    )
}

internal fun LazyListScope.ingredients(
    recipe: Recipe
){
    itemsIndexed(recipe.ingredients) { index, value ->
        AnimateInEffect(
            intervalStart = (index + 1) / (recipe.ingredients.size + 1).toFloat(),
            recipe = recipe,
            content = {
                if (value.contains("HEADER-")) {
                    Column {
                        Text(
                            text = value.removePrefix("HEADER-"),
                            style = MaterialTheme.typography.headlineSmall,
                            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
                        )
                        HorizontalDivider(
                            thickness = 2.dp,
                            color = if (recipe.bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.secondaryContainer else MaterialTheme.colorScheme.background,
                        )
                    }
                } else {
                    IngredientItem(recipe, value)
                }
            }
        )
    }
}

internal fun LazyListScope.steps(
    recipe: Recipe
)
{
    itemsIndexed(recipe.instructions) { index, _ ->
        AnimateInEffect(
            recipe = recipe,
            intervalStart = (index + 1) / (recipe.instructions.size + 1).toFloat(),
            content = {
                InstructionItem(recipe, index)
            })
    }
}

==> 0.2.0a.zip: menagerie_cookbook/shared/src/commonMain/kotlin/details/StepsAndDetails.kt <==
package details

import AnimateInEffect
import androidx.compose.animation.ExperimentalSharedTransitionApi
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.lazy.LazyListScope
import androidx.compose.foundation.lazy.grid.LazyGridScope
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.foundation.text.selection.SelectionContainer
import androidx.compose.material3.HorizontalDivider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.dp
import model.Recipe


/**
 * Created by abdulbasit on 29/07/2023.
 */

@OptIn(ExperimentalSharedTransitionApi::class)
internal fun LazyListScope.StepsAndDetails(
    recipe: Recipe,
    isLarge: Boolean,
) {
    item {
        recipeHeader(recipe, isLarge)
    }

    item {
        ingredientsHeader(recipe)
    }

    ingredients(recipe)

    item {
        stepsHeader(recipe)
    }

    steps(recipe)


}

@Composable
fun recipeHeader(recipe: Recipe, isLarge: Boolean)
{
    SelectionContainer {
        Text(
            text = recipe.title,
            style = MaterialTheme.typography.headlineLarge,
            fontWeight = FontWeight.W700,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }

    Text(
        text = recipe.description,
        style = if(isLarge) MaterialTheme.typography.headlineSmall else MaterialTheme.typography.bodyMedium,
        modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
    )

    Row {
        Text(
            text = "Prep Time: ".plus(recipe.prepTime.toString()),
            style = if(isLarge) MaterialTheme.typography.bodyLarge else MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
        Text(
            text = "Cook Time: ".plus(recipe.cookTime.toString()),
            style = if(isLarge) MaterialTheme.typography.bodyLarge else MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }
    Row {
        Text(
            text = "Total Time: ".plus(recipe.cookTime.plus(recipe.prepTime).toString()),
            style = if(isLarge) MaterialTheme.typography.bodyLarge else MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
        Text(
            text = "Serving Size: ".plus(recipe.servings),
            style = if(isLarge) MaterialTheme.typography.bodyLarge else MaterialTheme.typography.bodySmall,
            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
        )
    }
}

@Composable
fun ingredientsHeader(recipe: Recipe)
{
    AnimateInEffect(
        recipe = recipe,
        intervalStart = 0 / (recipe.instructions.size + recipe.ingredients.size + 2).toFloat(),
        content = {
            Text(
                text = "INGREDIENTS",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.W700,
                modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
            )
        })
}

@Composable
fun stepsHeader(recipe: Recipe)
{
    AnimateInEffect(
        recipe = recipe,
        intervalStart = (recipe.ingredients.size + 1) / (recipe.instructions.size + recipe.ingredients.size + 2).toFloat(),
        content = {
            Text(
                text = "STEPS",
                style = MaterialTheme.typography.headlineMedium,
                fontWeight = FontWeight.W700,
                modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
            )
        }
    )
}

internal fun LazyListScope.ingredients(
    recipe: Recipe
){
    itemsIndexed(recipe.ingredients) { index, value ->
        AnimateInEffect(
            intervalStart = (index + 1) / (recipe.ingredients.size + 1).toFloat(),
            recipe = recipe,
            content = {
                if (value.contains("HEADER-")) {
                    Column {
                        Text(
                            text = value.removePrefix("HEADER-"),
                            style = MaterialTheme.typography.headlineSmall,
                            modifier = Modifier.padding(top = 16.dp, start = 16.dp, end = 16.dp)
                        )
                        HorizontalDivider(
                            thickness = 2.dp,
                            color = if (recipe.bgColor != MaterialTheme.colorScheme.primaryContainer) MaterialTheme.colorScheme.secondaryContainer else MaterialTheme.colorScheme.background,
                        )
                    }
                } else {
                    IngredientItem(recipe, value)
                }
            }
        )
    }
}

internal fun LazyListScope.steps(
    recipe: Recipe
)
{
    itemsIndexed(recipe.instructions) { index, _ ->
        AnimateInEffect(
            recipe = recipe,
            intervalStart = (index + 1) / (recipe.instructions.size + 1).toFloat(),
            content = {
                InstructionItem(recipe, index)
            })
    }
}
